package com.gic.haoban.manage.service.service.out.impl;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import cn.hutool.core.collection.CollectionUtil;

import com.alibaba.fastjson.JSONObject;
import com.gic.api.base.commons.Page;
import com.gic.enterprise.api.dto.StoreDTO;
import com.gic.enterprise.api.dto.StorePhotoDTO;
import com.gic.enterprise.api.service.StoreService;
import com.gic.haoban.base.api.common.BasePageInfo;
import com.gic.haoban.common.utils.PageUtil;
import com.gic.haoban.common.utils.UuidUtil;
import com.gic.haoban.manage.api.dto.AuditDTO;
import com.gic.haoban.manage.api.dto.StoreAddressDTO;
import com.gic.haoban.manage.api.enums.StoreFieldEnum;
import com.gic.haoban.manage.api.service.AuditApiService;
import com.gic.haoban.manage.service.dao.mapper.DepartmentMapper;
import com.gic.haoban.manage.service.dao.mapper.StaffMapper;
import com.gic.haoban.manage.service.dao.mapper.TabHaobanAuditMapper;
import com.gic.haoban.manage.service.entity.TabHaobanAudit;
import com.gic.haoban.manage.service.entity.TabHaobanDepartment;
import com.gic.haoban.manage.service.entity.TabHaobanStaff;
import com.github.pagehelper.PageHelper;

/**
 * Created by tgs on 2020/2/9.
 */
@Service
public class AuditApiServiceImpl implements AuditApiService{
	private static Logger logger  = LoggerFactory.getLogger(AuditApiServiceImpl.class);

	@Autowired
	private TabHaobanAuditMapper auditMapper;
	@Autowired
	private DepartmentMapper departmentMapper;
	@Autowired
	private StaffMapper staffMapper;
	@Autowired
	private StoreService storeService;
	
	@Override
	public Page<AuditDTO> page(Integer auditType, String search,String wxEnterpriseId,
			String enterpriseId,Integer auditStatus, BasePageInfo pageInfo) {
		List<String> storeIds = new ArrayList<>();
		List<String> staffIds = new ArrayList<>();
		if(StringUtils.isNotEmpty(search)){
			List<TabHaobanDepartment> storeList = departmentMapper.listStoreLikeName(search);
			if(CollectionUtil.isNotEmpty(storeList)){
				storeIds = storeList.stream().map(s->s.getRelatedId()).collect(Collectors.toList());
			}
			List<TabHaobanStaff> staffList = staffMapper.listLikeName(search);
			if(CollectionUtil.isNotEmpty(staffList)){
				staffIds = staffList.stream().map(s->s.getStaffId()).collect(Collectors.toList());
			}
		}
		PageHelper.startPage(pageInfo.getPageNum(), pageInfo.getPageSize());
		com.github.pagehelper.Page<TabHaobanAudit> page = auditMapper.page(auditType, storeIds, staffIds, wxEnterpriseId,enterpriseId,auditStatus);
		return PageUtil.changePageHelperToCurrentPage( page,AuditDTO.class);
	}
	@Transactional
	@Override
	public void audit(String auditId) {
		TabHaobanAudit tab = auditMapper.selectByPrimaryKey(auditId);
		if(tab==null){
			return;
		}
		tab.setAuditId(auditId);
		tab.setAuditStatus(1);
		tab.setUpdateTime(new Date());
		auditMapper.updateByPrimaryKeySelective(tab);	
		String storeId = tab.getCommitStoreId();
		String oldValue = tab.getOldValue();
		String newValue = tab.getNewValue();
		String changeField = tab.getChangeField();
		this.editStoreInfo(storeId, changeField, oldValue, newValue);
	}
	@Override
	public void refuse(String auditId, String auditReason) {
		TabHaobanAudit tab = new TabHaobanAudit();
		tab.setAuditId(auditId);
		tab.setAuditStatus(0);
		tab.setUpdateTime(new Date());
		tab.setAuditReason(auditReason);
		auditMapper.updateByPrimaryKeySelective(tab);			
	}
	@Override
	public int  save(Integer auditType, String enterpriseId,
			String commitStaffId, String commitStoreId, String changeField,
			String oldValue, String newValue) {
		TabHaobanStaff staff = staffMapper.selectByPrimaryKey(commitStaffId);
		if(staff == null){
			return 0;
		}
		TabHaobanAudit tab = new TabHaobanAudit();	
		tab.setAuditId(UuidUtil.randomUUID());
		tab.setAuditStatus(0);
		tab.setAuditType(auditType);
		tab.setChangeField(changeField);
		tab.setCommitName(null);
		tab.setCommitStaffId(commitStaffId);
		tab.setCommitStaffImg(staff.getHeadImg());
		tab.setCommitStaffName(staff.getStaffName());
		tab.setCommitStoreId(commitStoreId);
		tab.setCommitTime(new Date());
		tab.setCreateTime(new Date());
		tab.setEnterpriseId(enterpriseId);
		tab.setNewValue(newValue);
		tab.setOldValue(oldValue);
		tab.setStatusFlag(1);
		tab.setUpdateTime(new Date());
		return auditMapper.insertSelective(tab);
	}
	@Override
	public void editStoreInfo(String storeId, String changeField,
			String oldValue, String newValue) {
		logger.info("===================进11");
		StoreDTO store = storeService.getStore(storeId);
		if(!StoreFieldEnum.STORE_IMAG.getValue().equals(changeField)){
			 //非门店图片修改
			logger.info("===================进222");
			getStoreDTO( store, changeField, oldValue, newValue);
			storeService.saveOrUpdateStore(store);
		 }else{
			 //门店图片修改
				logger.info("===================进333");
			 storeService.updateStorePhotos(storeId, newValue);
		 }		
	}
	void getStoreDTO(StoreDTO store,String changeField,String oldValue,String newValue){
		logger.info("==========================>changeField={}",changeField);
		if(StoreFieldEnum.BUSINESS_TIME_STRING.getValue().equals(changeField)){
			SimpleDateFormat sdf = new SimpleDateFormat("HH:mm");
			//营业时间
			String [] newValues = newValue.split("-");
			String openTime = newValues[0];
			String closeTime = newValues[1];
			Date date1 = null;
			Date date2 = null;
			try {
				date1 = sdf.parse(openTime);
			} catch (ParseException e) {
				e.printStackTrace();
			}
			try {
				date2 = sdf.parse(closeTime);
			} catch (ParseException e) {
				e.printStackTrace();
			}
			store.setOpenTime(date1);
			store.setCloseTime(date2);
		}else if(StoreFieldEnum.CONACTS_PHONE.getValue().equals(changeField)){
			//联系电话
			store.setConactsPhone(newValue);
		}else if(StoreFieldEnum.STORE_ADDRESS.getValue().equals(changeField)){
			logger.info("==========================>进来333");
			//门店地址
			StoreAddressDTO obj = JSONObject.parseObject(newValue,StoreAddressDTO.class);
			String areaId = obj.getAreaId();
			String storeAddress = obj.getStoreAddress();
			logger.info("==========================>areaId={},storeAddress={},newValue={}",areaId,storeAddress,newValue);
			String arr[] = storeAddress.split(" ");
			store.setAreaId(areaId);
			store.setFullArea(arr[0]);
			store.setStoreAddress(arr[1]);
		}else if(StoreFieldEnum.STORE_AREA.getValue().equals(changeField)){
			//门店面积
			store.setStoreArea(Double.parseDouble(newValue));
		}else if(StoreFieldEnum.STORE_NAME.getValue().equals(changeField)){
			//门店名字
			store.setStoreName(newValue);
		}else if(StoreFieldEnum.STORE_IMAG.getValue().equals(changeField)){
			//门店图片
		}
	}
}
